using System;
using System.Collections.Generic;
using System.Linq;
using EdFi.OdsApi.Sdk;
using EdFi.OdsApi.Models.Resources;
using RestSharp;
  
namespace EdFi.OdsApi.Api.Resources 
{
    public class StudentAssessmentsApi 
    {
        private readonly IRestClient client;

        public StudentAssessmentsApi(IRestClient client)
        {
            this.client = client;
        }
      
        /// <summary>
        /// Retrieves resources based with paging capabilities (using the &quot;Get All&quot; pattern). This GET operation provides access to resources using the &quot;Get All&quot; pattern. In this version of the API there is support for paging.
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<StudentAssessment>> GetStudentAssessmentsAll(int? offset= null, int? limit= null) 
        {
            var request = new RestRequest("/studentAssessments", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            request.AddHeader("Accept", "application/json");
            var response = client.Execute<List<StudentAssessment>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves resources matching values of an example resource (using the &quot;Get By Example&quot; pattern). This GET operation provides access to resources using the &quot;Get by Example&quot; search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <param name="identifier">A unique number or alphanumeric code assigned to an assessment administered to a student.</param>
        /// <param name="assessmentIdentifier">A unique number or alphanumeric code assigned to an assessment.</param>
        /// <param name="@namespace">Namespace for the Assessment.</param>
        /// <param name="studentUniqueId">A unique alphanumeric code assigned to a student.</param>
        /// <param name="administrationEnvironmentType">The environment in which the test was administered. For example:          Electronic          Classroom          Testing Center          ...</param>
        /// <param name="eventCircumstanceType">An unusual event occurred during the administration of the assessment. This could include fire alarm, student became ill, etc.</param>
        /// <param name="whenAssessedGradeLevelDescriptor">The grade level of a student when assessed.</param>
        /// <param name="administrationLanguageDescriptor">The language in which an assessment is written and/or administered.</param>
        /// <param name="reasonNotTestedType">The primary reason student is not tested. For example:          Absent          Refusal by parent          Refusal by student          Medical waiver          Illness          Disruptive behavior          LEP Exempt          ...</param>
        /// <param name="retestIndicatorType">Indicator if the test was retaken. For example:          Primary administration          First retest          Second retest          ...</param>
        /// <param name="administrationDate">The date and time an assessment was completed by the student. The use of ISO-8601 formats with a timezone designator (UTC or time offset) is recommended in order to prevent ambiguity due to time zones.</param>
        /// <param name="administrationEndDate">The date and time an assessment administration ended.</param>
        /// <param name="serialNumber">The unique number for the assessment form or answer document.</param>
        /// <param name="eventDescription">Describes special events that occur before during or after the assessment session that may impact use of results.</param>
        /// <param name="id"></param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<StudentAssessment>> GetStudentAssessmentsByExample(int? offset= null, int? limit= null, string identifier= null, string assessmentIdentifier= null, string @namespace= null, string studentUniqueId= null, string administrationEnvironmentType= null, string eventCircumstanceType= null, string whenAssessedGradeLevelDescriptor= null, string administrationLanguageDescriptor= null, string reasonNotTestedType= null, string retestIndicatorType= null, DateTime? administrationDate= null, DateTime? administrationEndDate= null, string serialNumber= null, string eventDescription= null, string id= null) 
        {
            var request = new RestRequest("/studentAssessments", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            if (identifier != null)
                request.AddParameter("identifier", identifier);
            if (assessmentIdentifier != null)
                request.AddParameter("assessmentIdentifier", assessmentIdentifier);
            if (@namespace != null)
                request.AddParameter("@namespace", @namespace);
            if (studentUniqueId != null)
                request.AddParameter("studentUniqueId", studentUniqueId);
            if (administrationEnvironmentType != null)
                request.AddParameter("administrationEnvironmentType", administrationEnvironmentType);
            if (eventCircumstanceType != null)
                request.AddParameter("eventCircumstanceType", eventCircumstanceType);
            if (whenAssessedGradeLevelDescriptor != null)
                request.AddParameter("whenAssessedGradeLevelDescriptor", whenAssessedGradeLevelDescriptor);
            if (administrationLanguageDescriptor != null)
                request.AddParameter("administrationLanguageDescriptor", administrationLanguageDescriptor);
            if (reasonNotTestedType != null)
                request.AddParameter("reasonNotTestedType", reasonNotTestedType);
            if (retestIndicatorType != null)
                request.AddParameter("retestIndicatorType", retestIndicatorType);
            if (administrationDate != null)
                request.AddParameter("administrationDate", administrationDate);
            if (administrationEndDate != null)
                request.AddParameter("administrationEndDate", administrationEndDate);
            if (serialNumber != null)
                request.AddParameter("serialNumber", serialNumber);
            if (eventDescription != null)
                request.AddParameter("eventDescription", eventDescription);
            if (id != null)
                request.AddParameter("id", id);
            request.AddHeader("Accept", "application/json");
            var response = client.Execute<List<StudentAssessment>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        /// </summary>
        /// <param name="assessmentIdentifier">A unique number or alphanumeric code assigned to an assessment.</param>
        /// <param name="@namespace">Namespace for the Assessment.</param>
        /// <param name="identifier">A unique number or alphanumeric code assigned to an assessment administered to a student.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<StudentAssessment> GetStudentAssessmentByKey(string assessmentIdentifier, string @namespace, string identifier, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/studentAssessments", Method.GET);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (assessmentIdentifier == null || @namespace == null || identifier == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            if (assessmentIdentifier != null)
                request.AddParameter("assessmentIdentifier", assessmentIdentifier);
            if (@namespace != null)
                request.AddParameter("@namespace", @namespace);
            if (identifier != null)
                request.AddParameter("identifier", identifier);
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/json");
            var response = client.Execute<StudentAssessment>(request);

            return response;
        }
        /// <summary>
        /// Creates or updates resources based on the natural key values of the supplied resource. The POST operation can be used to create or update resources. In database terms, this is often referred to as an &quot;upsert&quot; operation (insert + update).  Clients should NOT include the resource &quot;id&quot; in the JSON body because it will result in an error (you must use a PUT operation to update a resource by &quot;id&quot;). The web service will identify whether the resource already exists based on the natural key values provided, and update or create the resource appropriately.
        /// </summary>
        /// <param name="body">The JSON representation of the &quot;studentAssessment&quot; resource to be created or updated.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse PostStudentAssessments(StudentAssessment body) 
        {
            var request = new RestRequest("/studentAssessments", Method.POST);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (body == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddBody(body);
            request.Parameters.First(param => param.Type == ParameterType.RequestBody).Name = "application/json";
            var response = client.Execute(request);

            var location = response.Headers.FirstOrDefault(x => x.Name == "Location");

            if (location != null && !string.IsNullOrWhiteSpace(location.Value.ToString()))
                body.id = location.Value.ToString().Split('/').Last();
            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<StudentAssessment> GetStudentAssessmentsById(string id, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/studentAssessments/{id}", Method.GET);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/json");
            var response = client.Execute<StudentAssessment>(request);

            return response;
        }
        /// <summary>
        /// Updates or creates a resource based on the resource identifier. The PUT operation is used to update or create a resource by identifier.  If the resource doesn't exist, the resource will be created using that identifier.  Additionally, natural key values cannot be changed using this operation, and will not be modified in the database.  If the resource &quot;id&quot; is provided in the JSON body, it will be ignored as well.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be updated.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the PUT from updating a resource modified by another consumer.</param>
        /// <param name="body">The JSON representation of the &quot;studentAssessment&quot; resource to be updated.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse PutStudentAssessment(string id, string IfMatch, StudentAssessment body) 
        {
            var request = new RestRequest("/studentAssessments/{id}", Method.PUT);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null || body == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            request.AddBody(body);
            request.Parameters.First(param => param.Type == ParameterType.RequestBody).Name = "application/json";
            var response = client.Execute(request);

            var location = response.Headers.FirstOrDefault(x => x.Name == "Location");

            if (location != null && !string.IsNullOrWhiteSpace(location.Value.ToString()))
                body.id = location.Value.ToString().Split('/').Last();
            return response;
        }
        /// <summary>
        /// Deletes an existing resource using the resource identifier. The DELETE operation is used to delete an existing resource by identifier.  If the resource doesn't exist, an error will result (the resource will not be found).
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be deleted.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the DELETE from removing a resource modified by another consumer.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse DeleteStudentAssessmentById(string id, string IfMatch= null) 
        {
            var request = new RestRequest("/studentAssessments/{id}", Method.DELETE);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            var response = client.Execute(request);

            return response;
        }
        }
    }

