using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace EdFi.OdsApi.Models.EnrollmentComposite 
{
    public class LocalEducationAgency 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// The identifier assigned to a local education agency by the State Education Agency (SEA).
        /// </summary>
        public int? localEducationAgencyId { get; set; }

        /// <summary>
        /// The identifier assigned to an education organization by the StateEducationAgency (SEA).
        /// </summary>
        public string stateOrganizationId { get; set; }

        /// <summary>
        /// The full, legally accepted name of the institution.
        /// </summary>
        public string nameOfInstitution { get; set; }

        /// <summary>
        /// A short name for the institution.
        /// </summary>
        public string shortNameOfInstitution { get; set; }

        /// <summary>
        /// The public web site address (URL) for the EducationOrganization.
        /// </summary>
        public string webSite { get; set; }

        /// <summary>
        /// The current operational status of the EducationOrganization (e.g., active, inactive).
        /// </summary>
        public string operationalStatusType { get; set; }

        /// <summary>
        /// The category of local education agency/district. For example: Independent or Charter.
        /// </summary>
        public string categoryType { get; set; }

        /// <summary>
        /// A school or agency providing free public elementary or secondary education to eligible students under a specific charter granted by the state legislature or other appropriate authority and designated by such authority to be a charter school.
        /// </summary>
        public string charterStatusType { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationAddresses.  
        /// </summary>
        public List<LocalEducationAgency_educationOrganizationAddress> addresses { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationCategories.  
        /// </summary>
        public List<LocalEducationAgency_educationOrganizationCategory> educationOrganizationCategories { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationIdentificationCodes.  
        /// </summary>
        public List<LocalEducationAgency_educationOrganizationIdentificationCode> identificationCodes { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationInstitutionTelephones.  
        /// </summary>
        public List<LocalEducationAgency_educationOrganizationInstitutionTelephone> institutionTelephones { get; set; }

        }
}

