using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace EdFi.OdsApi.Models.Resources 
{
    public class GradebookEntry 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related GradingPeriod resource.
        /// </summary>
        public GradingPeriodReference gradingPeriodReference { get; set; }

        /// <summary>
        /// A reference to the related Section resource.
        /// </summary>
        public SectionReference sectionReference { get; set; }

        /// <summary>
        /// The date the assignment, homework, or assessment was assigned or executed.
        /// </summary>
        public DateTime? dateAssigned { get; set; }

        /// <summary>
        /// A description of the assignment, homework, or classroom assessment.
        /// </summary>
        public string description { get; set; }

        /// <summary>
        /// The name or title of the activity to be recorded in the GradebookEntry.
        /// </summary>
        public string title { get; set; }

        /// <summary>
        /// The type of the GradebookEntry; for example, homework, assignment, quiz, unit test, oral presentation, etc.
        /// </summary>
        public string type { get; set; }

        /// <summary>
        /// An unordered collection of gradebookEntryLearningObjectives.  LearningObjectives associated with the GradebookEntry.
        /// </summary>
        public List<GradebookEntryLearningObjective> learningObjectives { get; set; }

        /// <summary>
        /// An unordered collection of gradebookEntryLearningStandards.  LearningStandard(s) associated with the GradebookEntry.
        /// </summary>
        public List<GradebookEntryLearningStandard> learningStandards { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

