using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace EdFi.OdsApi.Models.Resources 
{
    public class Intervention 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related EducationOrganization resource.
        /// </summary>
        public EducationOrganizationReference educationOrganizationReference { get; set; }

        /// <summary>
        /// The start date for the intervention implementation.
        /// </summary>
        public DateTime? beginDate { get; set; }

        /// <summary>
        /// The way in which an intervention was implemented: individual, small group, whole class, or whole school.
        /// </summary>
        public string deliveryMethodType { get; set; }

        /// <summary>
        /// The end date for the intervention implementation.
        /// </summary>
        public DateTime? endDate { get; set; }

        /// <summary>
        /// The way in which an intervention is used: curriculum, supplement, or practice.
        /// </summary>
        public string classType { get; set; }

        /// <summary>
        /// A unique number or alphanumeric code assigned to an intervention.
        /// </summary>
        public string identificationCode { get; set; }

        /// <summary>
        /// An unordered collection of interventionAppropriateGradeLevels.  Grade levels for the Intervention-if omitted, considered generally applicable.
        /// </summary>
        public List<InterventionAppropriateGradeLevel> appropriateGradeLevels { get; set; }

        /// <summary>
        /// An unordered collection of interventionAppropriateSexes.  Sexes for the Intervention. If omitted, considered generally applicable.
        /// </summary>
        public List<InterventionAppropriateSex> appropriateSexes { get; set; }

        /// <summary>
        /// An unordered collection of interventionDiagnoses.  Targeted purpose of the Intervention (e.g., attendance issue, dropout risk).
        /// </summary>
        public List<InterventionDiagnosis> diagnoses { get; set; }

        /// <summary>
        /// An unordered collection of interventionEducationContents.  Relates the education content source to the education content.
        /// </summary>
        public List<InterventionEducationContent> educationContents { get; set; }

        /// <summary>
        /// An unordered collection of interventionInterventionPrescriptions.  The reference to the intervention prescription being followed in this intervention implementation.
        /// </summary>
        public List<InterventionInterventionPrescription> interventionPrescriptions { get; set; }

        /// <summary>
        /// An unordered collection of interventionLearningResourceMetadataURIs.  The URI (typical a URL) pointing to the metadata entry in a LRMI metadata repository, which describes this content item.
        /// </summary>
        public List<InterventionLearningResourceMetadataURI> learningResourceMetadataURIs { get; set; }

        /// <summary>
        /// An unordered collection of interventionMeetingTimes.  The times at which this intervention is scheduled to meet.
        /// </summary>
        public List<InterventionMeetingTime> meetingTimes { get; set; }

        /// <summary>
        /// An unordered collection of interventionPopulationServeds.  A subset of students that are the focus of the Intervention.
        /// </summary>
        public List<InterventionPopulationServed> populationServeds { get; set; }

        /// <summary>
        /// An unordered collection of interventionStaffs.  Relates the staff member associated with the Intervention.
        /// </summary>
        public List<InterventionStaff> staffs { get; set; }

        /// <summary>
        /// An unordered collection of interventionURIs.  The URI (typical a URL) pointing to an education content item.
        /// </summary>
        public List<InterventionURI> uris { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

