using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace EdFi.OdsApi.Models.Resources 
{
    public class InterventionPrescription 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related EducationOrganization resource.
        /// </summary>
        public EducationOrganizationReference educationOrganizationReference { get; set; }

        /// <summary>
        /// The way in which an intervention was implemented: individual, small group, whole class, or whole school.
        /// </summary>
        public string deliveryMethodType { get; set; }

        /// <summary>
        /// The way in which an intervention is used: curriculum, supplement, or practice.
        /// </summary>
        public string interventionClassType { get; set; }

        /// <summary>
        /// A unique number or alphanumeric code assigned to an intervention prescription.
        /// </summary>
        public string identificationCode { get; set; }

        /// <summary>
        /// An unordered collection of interventionPrescriptionAppropriateGradeLevels.  Grade levels for the prescribed intervention. If omitted, considered generally applicable.
        /// </summary>
        public List<InterventionPrescriptionAppropriateGradeLevel> appropriateGradeLevels { get; set; }

        /// <summary>
        /// An unordered collection of interventionPrescriptionAppropriateSexes.  Sexes for the InterventionPrescription. If omitted, considered generally applicable.
        /// </summary>
        public List<InterventionPrescriptionAppropriateSex> appropriateSexes { get; set; }

        /// <summary>
        /// An unordered collection of interventionPrescriptionDiagnoses.  Targeted purpose of the InterventionPrescription (e.g., attendance issue, dropout risk).
        /// </summary>
        public List<InterventionPrescriptionDiagnosis> diagnoses { get; set; }

        /// <summary>
        /// An unordered collection of interventionPrescriptionEducationContents.  Relates the education content source to the education content.
        /// </summary>
        public List<InterventionPrescriptionEducationContent> educationContents { get; set; }

        /// <summary>
        /// An unordered collection of interventionPrescriptionLearningResourceMetadataURIs.  The URI (typical a URL) pointing to the metadata entry in a LRMI metadata repository, which describes this content item.
        /// </summary>
        public List<InterventionPrescriptionLearningResourceMetadataURI> learningResourceMetadataURIs { get; set; }

        /// <summary>
        /// An unordered collection of interventionPrescriptionPopulationServeds.  A subset of students that are the focus of the InterventionPrescription.
        /// </summary>
        public List<InterventionPrescriptionPopulationServed> populationServeds { get; set; }

        /// <summary>
        /// An unordered collection of interventionPrescriptionURIs.  The URI (typical a URL) pointing to an education content item.
        /// </summary>
        public List<InterventionPrescriptionURI> uris { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

