using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace EdFi.OdsApi.Models.Resources 
{
    public class LearningStandard 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related LearningStandard resource.
        /// </summary>
        public LearningStandardReference parentLearningStandardReference { get; set; }

        /// <summary>
        /// Subject area for the LearningStandard.
        /// </summary>
        public string academicSubjectDescriptor { get; set; }

        /// <summary>
        /// The official Course Title with which this learning standard is associated.
        /// </summary>
        public string courseTitle { get; set; }

        /// <summary>
        /// The text of the statement. The textual content that either describes a specific competency such as "Apply the Pythagorean Theorem to determine unknown side lengths in right triangles in real-world and mathematical problems in two and three dimensions." or describes a less granular group of competencies within the taxonomy of the standards document, e.g. "Understand and apply the Pythagorean Theorem," or "Geometry".
        /// </summary>
        public string description { get; set; }

        /// <summary>
        /// The identifier for the specific learning standard (e.g., 111.15.3.1.A).
        /// </summary>
        public string learningStandardId { get; set; }

        /// <summary>
        /// A code designated by the promulgating body to identify the statement, e.g. 1.N.3 (usually not globally unique).
        /// </summary>
        public string itemCode { get; set; }

        /// <summary>
        /// Namespace for the LearningStandard.
        /// </summary>
        public string @namespace { get; set; }

        /// <summary>
        /// One or more statements that describes the criteria used by teachers and students to check for attainment of a learning standard. This criteria gives clear indications as to the degree to which learning is moving through the Zone or Proximal Development toward independent achievement of the LearningStandard.
        /// </summary>
        public string successCriteria { get; set; }

        /// <summary>
        /// An unambiguous reference to the statement using a network-resolvable URI.
        /// </summary>
        public string uri { get; set; }

        /// <summary>
        /// The content standard from which the LearningStandard was derived.
        /// </summary>
        public LearningStandardContentStandard contentStandard { get; set; }

        /// <summary>
        /// An unordered collection of learningStandardGradeLevels.  The grade levels for the specific learning standard.
        /// </summary>
        public List<LearningStandardGradeLevel> gradeLevels { get; set; }

        /// <summary>
        /// An unordered collection of learningStandardIdentificationCodes.  A coding scheme that is used for identification and record-keeping purposes by schools, social services, or other agencies to refer to a learning standard.
        /// </summary>
        public List<LearningStandardIdentificationCode> identificationCodes { get; set; }

        /// <summary>
        /// An unordered collection of learningStandardPrerequisiteLearningStandards.  The unique identifier of a prerequisite learning standard item, a competency needed prior to learning this one. (Some items may have no prerequisites others may have one or more prerequisites. This should only be used to represent the immediate predecessors in a competency-based pathway, i.e. not prerequisites of prerequisites).
        /// </summary>
        public List<LearningStandardPrerequisiteLearningStandard> prerequisiteLearningStandards { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

