using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace EdFi.OdsApi.Models.Resources 
{
    public class StudentAssessment 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related Assessment resource.
        /// </summary>
        public AssessmentReference assessmentReference { get; set; }

        /// <summary>
        /// A reference to the related Student resource.
        /// </summary>
        public StudentReference studentReference { get; set; }

        /// <summary>
        /// The date and time an assessment was completed by the student. The use of ISO-8601 formats with a timezone designator (UTC or time offset) is recommended in order to prevent ambiguity due to time zones.
        /// </summary>
        public DateTime? administrationDate { get; set; }

        /// <summary>
        /// The date and time an assessment administration ended.
        /// </summary>
        public DateTime? administrationEndDate { get; set; }

        /// <summary>
        /// The environment in which the test was administered. For example:          Electronic          Classroom          Testing Center          ...
        /// </summary>
        public string administrationEnvironmentType { get; set; }

        /// <summary>
        /// The language in which an assessment is written and/or administered.
        /// </summary>
        public string administrationLanguageDescriptor { get; set; }

        /// <summary>
        /// An unusual event occurred during the administration of the assessment. This could include fire alarm, student became ill, etc.
        /// </summary>
        public string eventCircumstanceType { get; set; }

        /// <summary>
        /// Describes special events that occur before during or after the assessment session that may impact use of results.
        /// </summary>
        public string eventDescription { get; set; }

        /// <summary>
        /// The primary reason student is not tested. For example:          Absent          Refusal by parent          Refusal by student          Medical waiver          Illness          Disruptive behavior          LEP Exempt          ...
        /// </summary>
        public string reasonNotTestedType { get; set; }

        /// <summary>
        /// Indicator if the test was retaken. For example:          Primary administration          First retest          Second retest          ...
        /// </summary>
        public string retestIndicatorType { get; set; }

        /// <summary>
        /// The unique number for the assessment form or answer document.
        /// </summary>
        public string serialNumber { get; set; }

        /// <summary>
        /// A unique number or alphanumeric code assigned to an assessment administered to a student.
        /// </summary>
        public string identifier { get; set; }

        /// <summary>
        /// The grade level of a student when assessed.
        /// </summary>
        public string whenAssessedGradeLevelDescriptor { get; set; }

        /// <summary>
        /// An unordered collection of studentAssessmentAccommodations.  The specific type of special variation used in how an examination is presented, how it is administered, or how the test taker is allowed to respond. This generally refers to changes that do not substantially alter what the examinationmeasures. The proper use of accommodations does not substantially change academic level or performance criteria. For example:          Braille          Enlarged monitor view          Extra time          Large Print          Setting          Oral Administration          ...
        /// </summary>
        public List<StudentAssessmentAccommodation> accommodations { get; set; }

        /// <summary>
        /// An unordered collection of studentAssessmentItems.  NEEDS DOCUMENTATION
        /// </summary>
        public List<StudentAssessmentItem> items { get; set; }

        /// <summary>
        /// An unordered collection of studentAssessmentPerformanceLevels.  The performance level(s) achieved for the StudentAssessment.
        /// </summary>
        public List<StudentAssessmentPerformanceLevel> performanceLevels { get; set; }

        /// <summary>
        /// An unordered collection of studentAssessmentScoreResults.  A meaningful score or statistical expression of the performance of an individual. The results can be expressed as a number, percentile, range, level, etc.
        /// </summary>
        public List<StudentAssessmentScoreResult> scoreResults { get; set; }

        /// <summary>
        /// An unordered collection of studentAssessmentStudentObjectiveAssessments.  NEEDS DOCUMENTATION
        /// </summary>
        public List<StudentAssessmentStudentObjectiveAssessment> studentObjectiveAssessments { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

